#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>
#include <syslog.h>
#include <stdarg.h>

#include "defs.h"
#include "toolkit.h"
#include "loadconfig.h"
#include "log.h"
#include "miscutil.h"
#include "main.h"
#include "smtp.h"
#include "wblist.h"

int
logging(const char *errcode) {
	char	logline[BIGBUFSIZE] = "[qsheff]";
	int	loglevel = 0;

	if(errcode[0] == 'P') {
		switch(errcode[1]) {
		case 'V':
			loglevel = 3;
			sprintf(logline, "%s, VIRUS", logline);
			break;
		case 'F':
			loglevel = 5;
			sprintf(logline, "%s, FILTER", logline);
			break;
		case 'W':
			loglevel = 7;
			sprintf(logline, "%s, WBLIST", logline);
			break;
		case 'B':
			loglevel = 9;
			sprintf(logline, "%s, BODY", logline);
			break;
		case 'S':
			loglevel = 11;
			sprintf(logline, "%s, SUBJ", logline);
			break;
		case 'A':
			loglevel = 13;
			sprintf(logline, "%s, ATTACH", logline);
			break;
		case 'J':
			loglevel = 15;
			sprintf(logline, "%s, HEADER", logline);
			break;
		case 'H':
			loglevel = 17;
			sprintf(logline, "%s, EMPTY", logline);
			break;
		}

		sprintf(logline, "%s, queue=%s, recvfrom=%s, from=%s, to=%s, subj=`%s'", logline, dir_suffix, rfc821_recvfrom, rfc821_from, rfc821_to, rfc821_subj);

		if((errcode[1] == 'S') || (errcode[1] == 'B') || (errcode[1] == 'A') || (errcode[1] == 'W'))
			sprintf(logline, "%s, spam=`%s', rule=`%s'", logline, sfe_spamword, sfe_ruleline);
		else if(strncmp(sfe_ruleline, "ACCEPT", sizeof(sfe_ruleline)) == 0)
			sprintf(logline, "%s, domain=`%s', rule=`%s'", logline, sfe_spamword, sfe_ruleline);

	}
	else if(errcode[0] == 'T') {
		loglevel = 0;
		switch(errcode[1]) {
		case 'P':
			sprintf(logline, "%s, ERR, error=Parse, hint=exec_ripmime,chdir_tempdir", logline);
			break;
		case 'W':
			sprintf(logline, "%s, ERR, error=WBL, hint=open_wbl_file", logline);
			break;
		case 'A':
			sprintf(logline, "%s, ERR, error=ATTACH, hint=open_attachlist,opendir_tempdir", logline);
			break;
		case 'S':
			sprintf(logline, "%s, ERR, error=SUBJ, hint=open_subjrulefile", logline);
			break;
		case 'B':
			sprintf(logline, "%s, ERR, error=BODY, hint=opendir_tempdir,open_body", logline);
			break;
		case 'V':
			sprintf(logline, "%s, ERR, error=VIRUS, hint=exec_antivirus", logline);
			break;
		case 'F':
			sprintf(logline, "%s, ERR, error=FILTER, hint=exec_filter", logline);
			break;
		case 'Q':
			sprintf(logline, "%s, ERR, error=QUEUE, hint=chdir_workdir,open_mesg", logline);
			break;
		}

		sprintf(logline, "%s, queue=%s, from=%s, to=%s", logline, dir_suffix, rfc821_from, rfc821_to);
	}
	else {
		loglevel = 21;
		sprintf(logline, "%s, SAFE, queue=%s, recvfrom=%s, from=%s, to=%s, subj=`%s'", logline, dir_suffix, rfc821_recvfrom, rfc821_from, rfc821_to, rfc821_subj);
	}
	
	misc_setlogdir("/");
	misc_setlogfile(LOGFILE);
	if (misc_openlog() != 0) {
#ifdef DEBUG
		printf("ERROR! cannot open logfile %s\n", LOGFILE);
#endif
		return -1;
	}

	misc_setloglevel(debug_level);
	misc_debug(loglevel, "%s\n", logline);

	misc_closelog();

	return 0;
}



